from pgnp import handlers
from .util import TestBase

class TestHandlerDefault(TestBase):

    def test_parse(self):
        handler = handlers.HandlerDefault("")
        with open(self.path / "output.gmi", newline="") as f_in:
            expected = f_in.read()
        self.assertEqual("", handler.output)
        handler.parse()
        self.assertEqual(expected, handler.output)


class TestHandlerCitizen(TestBase):
    """Test Citizen home page parsing."""

    def setUp(self):
        super().setUp()
        self.url = "thephiladelphiacitizen.org"

    def test_get(self):
        """Confirm that our mock get request just supplies expected HTML."""
        handler = handlers.HandlerCitizen(self.url)
        with open(self.path / "input.html", "rb") as f_in:
            expected = f_in.read()
        response = handler.get()
        self.assertEqual(expected, response.content)

    def test_parse(self):
        """Test that correct gemtext is generated from the HTML."""
        handler = handlers.HandlerCitizen(self.url)
        with open(self.path / "output.gmi", newline="") as f_in:
            expected = f_in.read()
        self.assertEqual("", handler.output)
        handler.parse()
        self.assertEqual(expected, handler.output)


class TestHandlerCitizenCategory(TestHandlerCitizen):
    """Test Citizen category page parsing."""

    def setUp(self):
        super().setUp()
        self.url = "thephiladelphiacitizen.org/category/some-topic"


class TestHandlerCitizenArticle(TestHandlerCitizen):
    """Test Citizen article page parsing."""

    def setUp(self):
        super().setUp()
        self.url = "thephiladelphiacitizen.org/article"


class TestHandlerCitizenUnknown(TestHandlerCitizen):
    """Test handling of unknown Citizen page type."""

    def setUp(self):
        super().setUp()
        self.url = "thephiladelphiacitizen.org/some-random-page"


class TestHandlerWHYYNews(TestBase):
    # Set up a similar structure as for the Citizen handler above
    # Random things to note: test /news page, a basic article, a NPR article,
    # what else?

    def setUp(self):
        super().setUp()
        self.url = "whyy.org/news"

    def test_get(self):
        handler = handlers.HandlerWHYYNews(self.url)
        with open(self.path / "input.html", "rb") as f_in:
            expected = f_in.read()
        response = handler.get()
        self.assertEqual(expected, response.content)

    def test_parse(self):
        handler = handlers.HandlerWHYYNews(self.url)
        with open(self.path / "output.gmi", newline="") as f_in:
            expected = f_in.read()
        self.assertEqual("", handler.output)
        handler.parse()
        self.assertEqual(expected, handler.output)
